@@ -5,7 +5,7 @@ SELECT
     , USER_ID                        AS USER_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(TS, 1125899906842624)/1000) seconds AS TS
     , TXID                           AS TXID
-    , DECODE (ACTION, 1, 'RERUN', 2, 'RERUN_RECURSIVE', 3, 'CANCEL', 4, 'SUSPEND', 5, 'RESUME', 6, 'SET_STATE', 7, 'SET_EXIT_STATE', 8, 'IGNORE_DEPENDENCY', 9, 'IGNORE_DEP_RECURSIVE', 10, 'IGNORE_RESOURCE', 11, 'KILL', 12, 'ALTER_RUN_PROGRAM', 13, 'ALTER_RERUN_PROGRAM', 14, 'COMMENT_JOB', 15, 'SUBMITTED', 16, 'TRIGGER_FAILED', 17, 'TRIGGER_SUBMIT', 18, 'JOB_RESTARTABLE', 19, 'CHANGE_PRIORITY', 20, 'RENICE', 21, 'SUBMIT_SUSPENDED', 22, 'IGNORE_NAMED_RESOURCE', 23, 'TIMEOUT', 24, 'SET_RESOURCE_STATE', 25, 'JOB_IN_ERROR', 26, 'CLEAR_WARNING', 27, 'SET_WARNING', 28, 'JOB_UNREACHABLE', 29, 'SET_PARAMETERS', 30, 'DISABLE', 31, 'ENABLE', 32, 'CLONE') AS ACTION
+    , DECODE (ACTION, 1, 'RERUN', 2, 'RERUN_RECURSIVE', 3, 'CANCEL', 4, 'SUSPEND', 5, 'RESUME', 6, 'SET_STATE', 7, 'SET_EXIT_STATE', 8, 'IGNORE_DEPENDENCY', 9, 'IGNORE_DEP_RECURSIVE', 10, 'IGNORE_RESOURCE', 11, 'KILL', 12, 'ALTER_RUN_PROGRAM', 13, 'ALTER_RERUN_PROGRAM', 14, 'COMMENT_JOB', 15, 'SUBMITTED', 16, 'TRIGGER_FAILED', 17, 'TRIGGER_SUBMIT', 18, 'JOB_RESTARTABLE', 19, 'CHANGE_PRIORITY', 20, 'RENICE', 21, 'SUBMIT_SUSPENDED', 22, 'IGNORE_NAMED_RESOURCE', 23, 'TIMEOUT', 24, 'SET_RESOURCE_STATE', 25, 'JOB_IN_ERROR', 26, 'CLEAR_WARNING', 27, 'SET_WARNING', 28, 'JOB_UNREACHABLE', 29, 'SET_PARAMETERS', 30, 'DISABLE', 31, 'ENABLE', 32, 'CLONE', 33, 'APPROVE', 34, 'REJECT', 35, 'APPROVAL_REQUEST', 36, 'REVIEW_REQUEST', 37, 'KILL_RECURSIVE') AS ACTION
     , DECODE (OBJECT_TYPE, 17, 'JOB') AS OBJECT_TYPE
     , OBJECT_ID                      AS OBJECT_ID
     , ORIGIN_ID                      AS ORIGIN_ID
@@ -28,6 +28,11 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM CALENDAR;
+ALTER TABLE DEPENDENCY_DEFINITION
+    ADD RESOLVE_MODE integer DEFAULT 0 NOT NULL
+    ADD EXPIRED_AMOUNT integer
+    ADD EXPIRED_BASE integer
+    ADD SELECT_CONDITION varchar(1024);
 DROP VIEW SCI_C_DEPENDENCY_DEFINITION;
 DROP VIEW SCI_V_DEPENDENCY_DEFINITION;
 CREATE VIEW SCI_C_DEPENDENCY_DEFINITION AS
@@ -40,6 +45,10 @@ SELECT
     , DECODE (DMODE, 1, 'ALL_FINAL', 2, 'JOB_FINAL') AS DMODE
     , DECODE (STATE_SELECTION, 0, 'FINAL', 1, 'ALL_REACHABLE', 2, 'UNREACHABLE', 3, 'DEFAULT') AS STATE_SELECTION
     , CONDITION                      AS CONDITION
+    , DECODE (RESOLVE_MODE, 0, 'INTERNAL', 1, 'EXTERNAL', 2, 'BOTH') AS RESOLVE_MODE
+    , EXPIRED_AMOUNT                 AS EXPIRED_AMOUNT
+    , DECODE (EXPIRED_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS EXPIRED_BASE
+    , SELECT_CONDITION               AS SELECT_CONDITION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -56,6 +65,10 @@ SELECT
     , DECODE (DMODE, 1, 'ALL_FINAL', 2, 'JOB_FINAL') AS DMODE
     , DECODE (STATE_SELECTION, 0, 'FINAL', 1, 'ALL_REACHABLE', 2, 'UNREACHABLE', 3, 'DEFAULT') AS STATE_SELECTION
     , CONDITION                      AS CONDITION
+    , DECODE (RESOLVE_MODE, 0, 'INTERNAL', 1, 'EXTERNAL', 2, 'BOTH') AS RESOLVE_MODE
+    , EXPIRED_AMOUNT                 AS EXPIRED_AMOUNT
+    , DECODE (EXPIRED_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS EXPIRED_BASE
+    , SELECT_CONDITION               AS SELECT_CONDITION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -63,6 +76,10 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM DEPENDENCY_DEFINITION;
+ALTER TABLE DEPENDENCY_INSTANCE
+    ADD REQUIRED_SE_ID bigint;
+ALTER TABLE ARC_DEPENDENCY_INSTANCE
+    ADD REQUIRED_SE_ID bigint;
 DROP VIEW SCI_DEPENDENCY_INSTANCE;
 CREATE VIEW SCI_DEPENDENCY_INSTANCE AS
 SELECT 
@@ -72,6 +89,7 @@ SELECT
     , DEPENDENT_ID_ORIG              AS DEPENDENT_ID_ORIG
     , DECODE (DEPENDENCY_OPERATION, 1, 'AND', 2, 'OR') AS DEPENDENCY_OPERATION
     , REQUIRED_ID                    AS REQUIRED_ID
+    , REQUIRED_SE_ID                 AS REQUIRED_SE_ID
     , DECODE (STATE, 0, 'OPEN', 1, 'FULFILLED', 2, 'FAILED', 3, 'BROKEN', 4, 'DEFERRED', 8, 'CANCELLED') AS STATE
     , DECODE (IGNORE, 0, 'NO', 1, 'YES', 2, 'RECURSIVE') AS IGNORE
     , DI_ID_ORIG                     AS DI_ID_ORIG
@@ -116,6 +134,7 @@ SELECT
     , NAME                           AS NAME
     , VALUE                          AS VALUE
     , DECODE (IS_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_LOCAL
+    , DECODE (IS_LONG, 1, 'TRUE', 0, 'FALSE') AS IS_LONG
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -363,6 +382,19 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM EXIT_STATE_TRANS_PROFILE;
+DROP VIEW SCI_EXTENTS;
+CREATE VIEW SCI_EXTENTS AS
+SELECT 
+    ID 
+    , O_ID                           AS O_ID
+    , SME_ID                         AS SME_ID
+    , SEQUENCE                       AS SEQUENCE
+    , EXTENT                         AS EXTENT
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM EXTENTS;
 DROP VIEW SCI_C_FOLDER;
 DROP VIEW SCI_V_FOLDER;
 CREATE VIEW SCI_C_FOLDER AS
@@ -410,7 +442,7 @@ SELECT
     ID 
     , OBJECT_ID                      AS OBJECT_ID
     , G_ID                           AS G_ID
-    , DECODE (OBJECT_TYPE, 1, 'ENVIRONMENT', 18, 'EVENT', 6, 'FOLDER', 19, 'INTERVAL', 17, 'JOB', 9, 'JOB_DEFINITION', 10, 'NAMED_RESOURCE', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 15, 'SCOPE', 21, 'GROUP', 11, 'RESOURCE', 2, 'EXIT_STATE_DEFINITION', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 12, 'RESOURCE_STATE_MAPPING', 7, 'FOOTPRINT', 8, 'USER', 30, 'OBJECT_MONITOR', 0, 'SYSTEM') AS OBJECT_TYPE
+    , DECODE (OBJECT_TYPE, 1, 'ENVIRONMENT', 18, 'EVENT', 6, 'FOLDER', 19, 'INTERVAL', 17, 'JOB', 9, 'JOB_DEFINITION', 10, 'NAMED_RESOURCE', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 15, 'SCOPE', 21, 'GROUP', 11, 'RESOURCE', 2, 'EXIT_STATE_DEFINITION', 31, 'NICE_PROFILE', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 29, 'WATCH_TYPE', 12, 'RESOURCE_STATE_MAPPING', 7, 'FOOTPRINT', 8, 'USER', 30, 'OBJECT_MONITOR', 0, 'SYSTEM') AS OBJECT_TYPE
     , PRIVS                          AS PRIVS
     , DELETE_VERSION                 AS DELETE_VERSION
     , CREATOR_U_ID                   AS CREATOR_U_ID
@@ -482,6 +514,9 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM INSTANCE_VALUE;
+ALTER TABLE INTERVALL
+    ADD OBJ_ID bigint
+    ADD OBJ_TYPE integer;
 DROP VIEW SCI_INTERVALL;
 CREATE VIEW SCI_INTERVALL AS
 SELECT 
@@ -500,11 +535,48 @@ SELECT
     , DECODE (IS_MERGE, 1, 'TRUE', 0, 'FALSE') AS IS_MERGE
     , EMBEDDED_INT_ID                AS EMBEDDED_INT_ID
     , SE_ID                          AS SE_ID
+    , OBJ_ID                         AS OBJ_ID
+    , DECODE (OBJ_TYPE, 25, 'DISTRIBUTION', 8, 'USER', 9, 'JOB_DEFINITION', 11, 'RESOURCE', 15, 'SCOPE', 16, 'TRIGGER', 18, 'EVENT', 19, 'INTERVAL', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 28, 'RESOURCE_TEMPLATE', 88, 'INTERVAL_DISPATCHER') AS OBJ_TYPE
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM INTERVALL;
+-- Copyright (C) 2001,2002 topIT Informationstechnologie GmbH
+-- Copyright (C) 2003-2014 independIT Integrative Technologies GmbH
+
+CREATE TABLE INTERVAL_DISPATCHER (
+    ID                             bigint NOT NULL
+    , INT_ID                         bigint          NOT NULL
+    , SEQ_NO                         integer         NOT NULL
+    , NAME                           varchar(64)     NOT NULL
+    , SELECT_INT_ID                  bigint              NULL
+    , FILTER_INT_ID                  bigint              NULL
+    , IS_ENABLED                     integer         NOT NULL
+    , IS_ACTIVE                      integer         NOT NULL
+    , CREATOR_U_ID                   bigint          NOT NULL
+    , CREATE_TS                      bigint          NOT NULL
+    , CHANGER_U_ID                   bigint          NOT NULL
+    , CHANGE_TS                      bigint          NOT NULL
+);
+CREATE UNIQUE INDEX PK_INTERVAL_DISPATCHER
+ON INTERVAL_DISPATCHER(ID);
+DROP VIEW SCI_INTERVAL_DISPATCHER;
+CREATE VIEW SCI_INTERVAL_DISPATCHER AS
+SELECT 
+    ID 
+    , INT_ID                         AS INT_ID
+    , SEQ_NO                         AS SEQ_NO
+    , NAME                           AS NAME
+    , SELECT_INT_ID                  AS SELECT_INT_ID
+    , FILTER_INT_ID                  AS FILTER_INT_ID
+    , DECODE (IS_ENABLED, 1, 'TRUE', 0, 'FALSE') AS IS_ENABLED
+    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM INTERVAL_DISPATCHER;
 DROP VIEW SCI_INTERVAL_HIERARCHY;
 CREATE VIEW SCI_INTERVAL_HIERARCHY AS
 SELECT 
@@ -592,6 +664,33 @@ SELECT
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
     , INHERIT_PRIVS                  AS INHERIT_PRIVS
   FROM NAMED_RESOURCE;
+DROP VIEW SCI_NICE_PROFILE;
+CREATE VIEW SCI_NICE_PROFILE AS
+SELECT 
+    ID 
+    , NAME                           AS NAME
+    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , ACTIVE_TS                      AS ACTIVE_TS
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM NICE_PROFILE;
+DROP VIEW SCI_NICE_PROFILE_ENTRY;
+CREATE VIEW SCI_NICE_PROFILE_ENTRY AS
+SELECT 
+    ID 
+    , NP_ID                          AS NP_ID
+    , PREFERENCE                     AS PREFERENCE
+    , FOLDER_ID                      AS FOLDER_ID
+    , DECODE (IS_SUSPENDED, 0, 'NOSUSPEND', 1, 'SUSPEND', 2, 'ADMINSUSPEND') AS IS_SUSPENDED
+    , RENICE                         AS RENICE
+    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM NICE_PROFILE_ENTRY;
 DROP VIEW SCI_MEMBER;
 CREATE VIEW SCI_MEMBER AS
 SELECT 
@@ -612,6 +711,7 @@ SELECT
     , DECODE (OBJECT_TYPE, 9, 'JOB_DEFINITION', 2, 'EXIT_STATE_DEFINITION', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 6, 'FOLDER', 15, 'SCOPE', 10, 'NAMED_RESOURCE', 31, 'NICE_PROFILE', 11, 'RESOURCE', 1, 'ENVIRONMENT', 7, 'FOOTPRINT', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 12, 'RESOURCE_STATE_MAPPING', 8, 'USER', 16, 'TRIGGER', 17, 'JOB', 18, 'EVENT', 19, 'INTERVAL', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 21, 'GROUP', 23, 'PARAMETER', 24, 'POOL', 25, 'DISTRIBUTION', 29, 'WATCH_TYPE', 30, 'OBJECT_MONITOR') AS OBJECT_TYPE
     , DECODE (INFO_TYPE, 0, 'TEXT', 1, 'URL') AS INFO_TYPE
     , SEQUENCE_NUMBER                AS SEQUENCE_NUMBER
+    , TAG                            AS TAG
     , DESCRIPTION                    AS DESCRIPTION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
@@ -626,6 +726,7 @@ SELECT
     , DECODE (OBJECT_TYPE, 9, 'JOB_DEFINITION', 2, 'EXIT_STATE_DEFINITION', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 6, 'FOLDER', 15, 'SCOPE', 10, 'NAMED_RESOURCE', 31, 'NICE_PROFILE', 11, 'RESOURCE', 1, 'ENVIRONMENT', 7, 'FOOTPRINT', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 12, 'RESOURCE_STATE_MAPPING', 8, 'USER', 16, 'TRIGGER', 17, 'JOB', 18, 'EVENT', 19, 'INTERVAL', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 21, 'GROUP', 23, 'PARAMETER', 24, 'POOL', 25, 'DISTRIBUTION', 29, 'WATCH_TYPE', 30, 'OBJECT_MONITOR') AS OBJECT_TYPE
     , DECODE (INFO_TYPE, 0, 'TEXT', 1, 'URL') AS INFO_TYPE
     , SEQUENCE_NUMBER                AS SEQUENCE_NUMBER
+    , TAG                            AS TAG
     , DESCRIPTION                    AS DESCRIPTION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
@@ -706,11 +807,13 @@ SELECT
     ID 
     , SE_ID                          AS SE_ID
     , NAME                           AS NAME
-    , DECODE (TYPE, 10, 'REFERENCE', 20, 'CHILDREFERENCE', 30, 'CONSTANT', 40, 'RESULT', 50, 'PARAMETER', 60, 'EXPRESSION', 70, 'IMPORT', 80, 'DYNAMIC', 81, 'DYNAMICVALUE', 90, 'LOCAL_CONSTANT', 91, 'RESOURCEREFERENCE') AS TYPE
+    , DECODE (TYPE, 10, 'REFERENCE', 20, 'CHILDREFERENCE', 30, 'CONSTANT', 40, 'RESULT', 50, 'PARAMETER', 60, 'EXPRESSION', 70, 'IMPORT', 71, 'IMPORT_UNRESOLVED', 80, 'DYNAMIC', 81, 'DYNAMICVALUE', 90, 'LOCAL_CONSTANT', 91, 'RESOURCEREFERENCE') AS TYPE
     , DECODE (AGG_FUNCTION, 0, 'NONE', 61, 'AVG', 62, 'COUNT', 63, 'MIN', 64, 'MAX', 65, 'SUM') AS AGG_FUNCTION
     , DEFAULTVALUE                   AS DEFAULTVALUE
     , DECODE (IS_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_LOCAL
     , LINK_PD_ID                     AS LINK_PD_ID
+    , EXPORT_NAME                    AS EXPORT_NAME
+    , DECODE (IS_LONG, 1, 'TRUE', 0, 'FALSE') AS IS_LONG
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -722,11 +825,13 @@ SELECT
     ID 
     , SE_ID                          AS SE_ID
     , NAME                           AS NAME
-    , DECODE (TYPE, 10, 'REFERENCE', 20, 'CHILDREFERENCE', 30, 'CONSTANT', 40, 'RESULT', 50, 'PARAMETER', 60, 'EXPRESSION', 70, 'IMPORT', 80, 'DYNAMIC', 81, 'DYNAMICVALUE', 90, 'LOCAL_CONSTANT', 91, 'RESOURCEREFERENCE') AS TYPE
+    , DECODE (TYPE, 10, 'REFERENCE', 20, 'CHILDREFERENCE', 30, 'CONSTANT', 40, 'RESULT', 50, 'PARAMETER', 60, 'EXPRESSION', 70, 'IMPORT', 71, 'IMPORT_UNRESOLVED', 80, 'DYNAMIC', 81, 'DYNAMICVALUE', 90, 'LOCAL_CONSTANT', 91, 'RESOURCEREFERENCE') AS TYPE
     , DECODE (AGG_FUNCTION, 0, 'NONE', 61, 'AVG', 62, 'COUNT', 63, 'MIN', 64, 'MAX', 65, 'SUM') AS AGG_FUNCTION
     , DEFAULTVALUE                   AS DEFAULTVALUE
     , DECODE (IS_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_LOCAL
     , LINK_PD_ID                     AS LINK_PD_ID
+    , EXPORT_NAME                    AS EXPORT_NAME
+    , DECODE (IS_LONG, 1, 'TRUE', 0, 'FALSE') AS IS_LONG
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -858,9 +963,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM RESSOURCE;
-ALTER TABLE RESOURCE_ALLOCATION
-    ADD STICKY_NAME varchar(64)
-    ADD STICKY_PARENT bigint;
 DROP VIEW SCI_RESOURCE_ALLOCATION;
 CREATE VIEW SCI_RESOURCE_ALLOCATION AS
 SELECT 
@@ -908,9 +1010,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM RESOURCE_REQ_STATES;
-ALTER TABLE RESOURCE_REQUIREMENT
-    ADD STICKY_NAME varchar(64)
-    ADD STICKY_PARENT bigint;
 DROP VIEW SCI_C_RESOURCE_REQUIREMENT;
 DROP VIEW SCI_V_RESOURCE_REQUIREMENT;
 CREATE VIEW SCI_C_RESOURCE_REQUIREMENT AS
@@ -926,6 +1025,7 @@ SELECT
     , RSMP_ID                        AS RSMP_ID
     , EXPIRED_AMOUNT                 AS EXPIRED_AMOUNT
     , DECODE (EXPIRED_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS EXPIRED_BASE
+    , DECODE (IGNORE_ON_RERUN, 1, 'TRUE', 0, 'FALSE') AS IGNORE_ON_RERUN
     , DECODE (LOCKMODE, 255, 'N', 0, 'X', 2, 'SX', 4, 'S', 6, 'SC') AS LOCKMODE
     , CONDITION                      AS CONDITION
     , CREATOR_U_ID                   AS CREATOR_U_ID
@@ -947,6 +1047,7 @@ SELECT
     , RSMP_ID                        AS RSMP_ID
     , EXPIRED_AMOUNT                 AS EXPIRED_AMOUNT
     , DECODE (EXPIRED_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS EXPIRED_BASE
+    , DECODE (IGNORE_ON_RERUN, 1, 'TRUE', 0, 'FALSE') AS IGNORE_ON_RERUN
     , DECODE (LOCKMODE, 255, 'N', 0, 'X', 2, 'SX', 4, 'S', 6, 'SC') AS LOCKMODE
     , CONDITION                      AS CONDITION
     , CREATOR_U_ID                   AS CREATOR_U_ID
@@ -1227,6 +1328,8 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM SCHEDULING_ENTITY;
+ALTER TABLE SCHEDULING_HIERARCHY
+    ADD INT_ID bigint;
 DROP VIEW SCI_C_SCHEDULING_HIERARCHY;
 DROP VIEW SCI_V_SCHEDULING_HIERARCHY;
 CREATE VIEW SCI_C_SCHEDULING_HIERARCHY AS
@@ -1236,6 +1339,7 @@ SELECT
     , SE_CHILD_ID                    AS SE_CHILD_ID
     , ALIAS_NAME                     AS ALIAS_NAME
     , DECODE (IS_STATIC, 1, 'STATIC', 0, 'DYNAMIC') AS IS_STATIC
+    , DECODE (IS_DISABLED, 0, 'ENABLED', 1, 'DISABLED') AS IS_DISABLED
     , PRIORITY                       AS PRIORITY
     , DECODE (SUSPEND, 1, 'CHILDSUSPEND', 2, 'NOSUSPEND', 3, 'SUSPEND') AS SUSPEND
     , RESUME_AT                      AS RESUME_AT
@@ -1243,6 +1347,7 @@ SELECT
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (MERGE_MODE, 1, 'MERGE_LOCAL', 2, 'MERGE_GLOBAL', 3, 'NOMERGE', 4, 'FAILURE') AS MERGE_MODE
     , ESTP_ID                        AS ESTP_ID
+    , INT_ID                         AS INT_ID
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -1256,6 +1361,7 @@ SELECT
     , SE_CHILD_ID                    AS SE_CHILD_ID
     , ALIAS_NAME                     AS ALIAS_NAME
     , DECODE (IS_STATIC, 1, 'STATIC', 0, 'DYNAMIC') AS IS_STATIC
+    , DECODE (IS_DISABLED, 0, 'ENABLED', 1, 'DISABLED') AS IS_DISABLED
     , PRIORITY                       AS PRIORITY
     , DECODE (SUSPEND, 1, 'CHILDSUSPEND', 2, 'NOSUSPEND', 3, 'SUSPEND') AS SUSPEND
     , RESUME_AT                      AS RESUME_AT
@@ -1263,6 +1369,7 @@ SELECT
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (MERGE_MODE, 1, 'MERGE_LOCAL', 2, 'MERGE_GLOBAL', 3, 'NOMERGE', 4, 'FAILURE') AS MERGE_MODE
     , ESTP_ID                        AS ESTP_ID
+    , INT_ID                         AS INT_ID
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -1270,9 +1377,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM SCHEDULING_HIERARCHY;
-ALTER TABLE SCOPE
-    ADD SALT varchar(64)
-    ADD METHOD integer DEFAULT 0 NOT NULL;
 DROP VIEW SCI_SCOPE;
 CREATE VIEW SCI_SCOPE AS
 SELECT 
@@ -1334,6 +1438,10 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM SME_COUNTER;
+ALTER TABLE SUBMITTED_ENTITY
+    ADD TIME_ZONE varchar(32);
+ALTER TABLE ARC_SUBMITTED_ENTITY
+    ADD TIME_ZONE varchar(32);
 DROP VIEW SCI_SUBMITTED_ENTITY;
 CREATE VIEW SCI_SUBMITTED_ENTITY AS
 SELECT 
@@ -1348,6 +1456,8 @@ SELECT
     , PARENT_ID                      AS PARENT_ID
     , SCOPE_ID                       AS SCOPE_ID
     , DECODE (IS_STATIC, 1, 'TRUE', 0, 'FALSE') AS IS_STATIC
+    , DECODE (IS_DISABLED, 1, 'TRUE', 0, 'FALSE') AS IS_DISABLED
+    , OLD_STATE                      AS OLD_STATE
     , DECODE (MERGE_MODE, 1, 'MERGE_LOCAL', 2, 'MERGE_GLOBAL', 3, 'NOMERGE', 4, 'FAILURE') AS MERGE_MODE
     , DECODE (STATE, 0, 'SUBMITTED', 1, 'DEPENDENCY_WAIT', 2, 'SYNCHRONIZE_WAIT', 3, 'RESOURCE_WAIT', 4, 'RUNNABLE', 5, 'STARTING', 6, 'STARTED', 7, 'RUNNING', 8, 'TO_KILL', 9, 'KILLED', 10, 'CANCELLED', 11, 'FINISHED', 12, 'FINAL', 13, 'BROKEN_ACTIVE', 14, 'BROKEN_FINISHED', 15, 'ERROR', 16, 'UNREACHABLE') AS STATE
     , JOB_ESD_ID                     AS JOB_ESD_ID
@@ -1380,7 +1490,9 @@ SELECT
     , DECODE (IS_SUSPENDED, 2, 'ADMINSUSPEND', 1, 'SUSPEND', 0, 'NOSUSPEND') AS IS_SUSPENDED
     , DECODE (IS_SUSPENDED_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_SUSPENDED_LOCAL
     , PRIORITY                       AS PRIORITY
+    , RAW_PRIORITY                   AS RAW_PRIORITY
     , NICE                           AS NICE
+    , NP_NICE                        AS NP_NICE
     , MIN_PRIORITY                   AS MIN_PRIORITY
     , AGING_AMOUNT                   AS AGING_AMOUNT
     , PARENT_SUSPENDED               AS PARENT_SUSPENDED
@@ -1395,12 +1507,47 @@ SELECT
     , timestamp('1970-01-01-00.00.00') + int(mod(START_TS, 1125899906842624)/1000) seconds AS START_TS
     , timestamp('1970-01-01-00.00.00') + int(mod(FINSH_TS, 1125899906842624)/1000) seconds AS FINSH_TS
     , timestamp('1970-01-01-00.00.00') + int(mod(FINAL_TS, 1125899906842624)/1000) seconds AS FINAL_TS
+    , IDLE_TIME                      AS IDLE_TIME
+    , DEPENDENCY_WAIT_TIME           AS DEPENDENCY_WAIT_TIME
+    , SUSPEND_TIME                   AS SUSPEND_TIME
+    , SYNC_TIME                      AS SYNC_TIME
+    , RESOURCE_TIME                  AS RESOURCE_TIME
+    , JOBSERVER_TIME                 AS JOBSERVER_TIME
+    , RESTARTABLE_TIME               AS RESTARTABLE_TIME
+    , CHILD_WAIT_TIME                AS CHILD_WAIT_TIME
+    , OP_SUSRES_TS                   AS OP_SUSRES_TS
+    , NPE_ID                         AS NPE_ID
+    , TIME_ZONE                      AS TIME_ZONE
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
     , ((NVL(FINAL_TS, TIMESTAMPDIFF(2, CURRENT TIMESTAMP - CURRENT TIMEZONE - TIMESTAMP('1970-01-01-00.00.00')) * 1000) - SUBMIT_TS) / 1000) - DEPENDENCY_WAIT_TIME AS PROCESS_TIME
   FROM SUBMITTED_ENTITY;
+DROP VIEW SCI_SUBMITTED_ENTITY_STATS;
+CREATE VIEW SCI_SUBMITTED_ENTITY_STATS AS
+SELECT 
+    ID 
+    , SME_ID                         AS SME_ID
+    , RERUN_SEQ                      AS RERUN_SEQ
+    , SCOPE_ID                       AS SCOPE_ID
+    , JOB_ESD_ID                     AS JOB_ESD_ID
+    , EXIT_CODE                      AS EXIT_CODE
+    , COMMANDLINE                    AS COMMANDLINE
+    , WORKDIR                        AS WORKDIR
+    , LOGFILE                        AS LOGFILE
+    , ERRLOGFILE                     AS ERRLOGFILE
+    , EXTPID                         AS EXTPID
+    , timestamp('1970-01-01-00.00.00') + int(mod(SYNC_TS, 1125899906842624)/1000) seconds AS SYNC_TS
+    , timestamp('1970-01-01-00.00.00') + int(mod(RESOURCE_TS, 1125899906842624)/1000) seconds AS RESOURCE_TS
+    , timestamp('1970-01-01-00.00.00') + int(mod(RUNNABLE_TS, 1125899906842624)/1000) seconds AS RUNNABLE_TS
+    , timestamp('1970-01-01-00.00.00') + int(mod(START_TS, 1125899906842624)/1000) seconds AS START_TS
+    , timestamp('1970-01-01-00.00.00') + int(mod(FINISH_TS, 1125899906842624)/1000) seconds AS FINISH_TS
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM SUBMITTED_ENTITY_STATS;
 DROP VIEW SCI_C_TEMPLATE_VARIABLE;
 DROP VIEW SCI_V_TEMPLATE_VARIABLE;
 CREATE VIEW SCI_C_TEMPLATE_VARIABLE AS
@@ -1440,6 +1587,7 @@ SELECT
     , MAIN_SE_ID                     AS MAIN_SE_ID
     , PARENT_SE_ID                   AS PARENT_SE_ID
     , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , DECODE (IS_INVERSE, 1, 'TRUE', 0, 'FALSE') AS IS_INVERSE
     , DECODE (ACTION, 0, 'SUBMIT', 1, 'RERUN') AS ACTION
     , DECODE (TYPE, 0, 'IMMEDIATE_LOCAL', 2, 'BEFORE_FINAL', 3, 'AFTER_FINAL', 1, 'IMMEDIATE_MERGE', 4, 'FINISH_CHILD', 5, 'UNTIL_FINISHED', 6, 'UNTIL_FINAL', 7, 'WARNING') AS TYPE
     , DECODE (IS_MASTER, 1, 'MASTER', 0, 'NOMASTER') AS IS_MASTER
@@ -1452,6 +1600,7 @@ SELECT
     , RESUME_IN                      AS RESUME_IN
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (IS_WARN_ON_LIMIT, 1, 'TRUE', 0, 'FALSE') AS IS_WARN_ON_LIMIT
+    , LIMIT_STATE                    AS LIMIT_STATE
     , MAX_RETRY                      AS MAX_RETRY
     , SUBMIT_OWNER_ID                AS SUBMIT_OWNER_ID
     , CONDITION                      AS CONDITION
@@ -1473,6 +1622,7 @@ SELECT
     , MAIN_SE_ID                     AS MAIN_SE_ID
     , PARENT_SE_ID                   AS PARENT_SE_ID
     , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , DECODE (IS_INVERSE, 1, 'TRUE', 0, 'FALSE') AS IS_INVERSE
     , DECODE (ACTION, 0, 'SUBMIT', 1, 'RERUN') AS ACTION
     , DECODE (TYPE, 0, 'IMMEDIATE_LOCAL', 2, 'BEFORE_FINAL', 3, 'AFTER_FINAL', 1, 'IMMEDIATE_MERGE', 4, 'FINISH_CHILD', 5, 'UNTIL_FINISHED', 6, 'UNTIL_FINAL', 7, 'WARNING') AS TYPE
     , DECODE (IS_MASTER, 1, 'MASTER', 0, 'NOMASTER') AS IS_MASTER
@@ -1485,6 +1635,7 @@ SELECT
     , RESUME_IN                      AS RESUME_IN
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (IS_WARN_ON_LIMIT, 1, 'TRUE', 0, 'FALSE') AS IS_WARN_ON_LIMIT
+    , LIMIT_STATE                    AS LIMIT_STATE
     , MAX_RETRY                      AS MAX_RETRY
     , SUBMIT_OWNER_ID                AS SUBMIT_OWNER_ID
     , CONDITION                      AS CONDITION
@@ -1497,6 +1648,50 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TRIGGER_DEFINITION;
+-- Copyright (C) 2001,2002 topIT Informationstechnologie GmbH
+-- Copyright (C) 2003-2014 independIT Integrative Technologies GmbH
+
+CREATE TABLE TRIGGER_PARAMETER (
+    ID                             bigint NOT NULL
+    , NAME                           varchar(64)     NOT NULL
+    , EXPRESSION                     varchar(1024)   NOT NULL
+    , TRIGGER_ID                     bigint          NOT NULL
+    , CREATOR_U_ID                   bigint          NOT NULL
+    , CREATE_TS                      bigint          NOT NULL
+    , CHANGER_U_ID                   bigint          NOT NULL
+    , CHANGE_TS                      bigint          NOT NULL
+    , VALID_FROM                   bigint NOT NULL
+    , VALID_TO                     bigint NOT NULL
+);
+CREATE INDEX PK_TRIGGER_PARAMETER
+ON TRIGGER_PARAMETER(ID);
+DROP VIEW SCI_C_TRIGGER_PARAMETER;
+DROP VIEW SCI_V_TRIGGER_PARAMETER;
+CREATE VIEW SCI_C_TRIGGER_PARAMETER AS
+SELECT 
+    ID 
+    , NAME                           AS NAME
+    , EXPRESSION                     AS EXPRESSION
+    , TRIGGER_ID                     AS TRIGGER_ID
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM TRIGGER_PARAMETER
+ WHERE VALID_TO = 9223372036854775807;
+CREATE VIEW SCI_V_TRIGGER_PARAMETER AS
+SELECT 
+    ID 
+    , NAME                           AS NAME
+    , EXPRESSION                     AS EXPRESSION
+    , TRIGGER_ID                     AS TRIGGER_ID
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+    , VALID_FROM
+    , VALID_TO
+  FROM TRIGGER_PARAMETER;
 DROP VIEW SCI_TRIGGER_QUEUE;
 CREATE VIEW SCI_TRIGGER_QUEUE AS
 SELECT 
@@ -1538,9 +1733,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TRIGGER_STATE;
-ALTER TABLE USERS
-    ADD SALT varchar(64)
-    ADD METHOD integer DEFAULT 0 NOT NULL;
 DROP VIEW SCI_USERS;
 CREATE VIEW SCI_USERS AS
 SELECT 
@@ -1548,12 +1740,52 @@ SELECT
     , NAME                           AS NAME
     , DECODE (IS_ENABLED, 1, 'TRUE', 0, 'FALSE') AS IS_ENABLED
     , DEFAULT_G_ID                   AS DEFAULT_G_ID
+    , DECODE (CONNECTION_TYPE, 0, 'PLAIN', 1, 'SSL', 2, 'SSL_AUTH') AS CONNECTION_TYPE
     , DELETE_VERSION                 AS DELETE_VERSION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM USERS;
+DROP VIEW SCI_USER_EQUIV;
+CREATE VIEW SCI_USER_EQUIV AS
+SELECT 
+    ID 
+    , U_ID                           AS U_ID
+    , DECODE (ALT_U_TYPE, 0, 'USER', 1, 'SERVER') AS ALT_U_TYPE
+    , ALT_U_ID                       AS ALT_U_ID
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM USER_EQUIV;
+DROP VIEW SCI_C_VERSIONED_EXTENTS;
+DROP VIEW SCI_V_VERSIONED_EXTENTS;
+CREATE VIEW SCI_C_VERSIONED_EXTENTS AS
+SELECT 
+    ID 
+    , O_ID                           AS O_ID
+    , SEQUENCE                       AS SEQUENCE
+    , EXTENT                         AS EXTENT
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+  FROM VERSIONED_EXTENTS
+ WHERE VALID_TO = 9223372036854775807;
+CREATE VIEW SCI_V_VERSIONED_EXTENTS AS
+SELECT 
+    ID 
+    , O_ID                           AS O_ID
+    , SEQUENCE                       AS SEQUENCE
+    , EXTENT                         AS EXTENT
+    , CREATOR_U_ID                   AS CREATOR_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
+    , CHANGER_U_ID                   AS CHANGER_U_ID
+    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
+    , VALID_FROM
+    , VALID_TO
+  FROM VERSIONED_EXTENTS;
 DROP VIEW SCI_C_WATCH_TYPE;
 DROP VIEW SCI_V_WATCH_TYPE;
 CREATE VIEW SCI_C_WATCH_TYPE AS
@@ -1606,25 +1838,5 @@ SELECT
     , timestamp('1970-01-01-00.00.00') + int(mod(WRITE_TIME, 1125899906842624)/1000) seconds AS WRITE_TIME
     , timestamp('1970-01-01-00.00.00') + int(mod(LAST_WRITE, 1125899906842624)/1000) seconds AS LAST_WRITE
   FROM RESOURCE_TRACE;
-CREATE TABLE SME2LOAD (ID BIGINT NOT NULL);
-CREATE INDEX SME2LOAD_IDX ON SME2LOAD (ID);
-CREATE INDEX SME_IDX ON SUBMITTED_ENTITY (MASTER_ID, ID, STATE, FINAL_TS);
-CREATE INDEX KILL_JOB_IDX ON KILL_JOB (SME_ID);
-CREATE INDEX AUDIT_TRAIL_IDX ON AUDIT_TRAIL (OBJECT_ID);
-CREATE INDEX ENTITY_VARIABLE_IDX ON ENTITY_VARIABLE (SME_ID);
-CREATE INDEX DEPENDENCY_INSTANCE_IDX ON DEPENDENCY_INSTANCE (DEPENDENT_ID);
-CREATE INDEX HIERARCHY_INSTANCE_IDX ON HIERARCHY_INSTANCE (CHILD_ID);
-UPDATE RESOURCE_ALLOCATION
-   SET STICKY_PARENT = (
-       SELECT MASTER_ID
-         FROM SUBMITTED_ENTITY
-        WHERE ID = SME_ID
-       )
- WHERE IS_STICKY = 1
-   AND SME_ID > 0;
-UPDATE RESOURCE_ALLOCATION
-   SET STICKY_PARENT = -SME_ID
- WHERE IS_STICKY = 1
-   AND SME_ID < 0;
-ALTER TABLE SCOPE ALTER PASSWD SET DATA TYPE VARCHAR(64);
+ALTER TABLE SCOPE ALTER NODE SET DATA TYPE VARCHAR(64);
 commit;
