@@ -57,6 +57,8 @@ CREATE TABLE SUBMITTED_ENTITY (
     , CHILD_SUSPENDED                int8            NOT NULL
     , WARN_COUNT                     int8            NOT NULL
     , WARN_LINK                      bigint              NULL
+    , APPROVAL_MODE                  int8            NOT NULL
+    , CHILD_APPROVAL_MODE            int8            NOT NULL
     , SUBMIT_TS                      bigint          NOT NULL
     , RESUME_TS                      bigint              NULL
     , SYNC_TS                        bigint              NULL
@@ -105,7 +107,7 @@ CREATE TABLE SUBMITTED_ENTITY (
 );
 CREATE UNIQUE INDEX PK_SUBMITTED_ENTITY
 ON SUBMITTED_ENTITY(ID);
-CREATE VIEW SCI_SUBMITTED_ENTITY (ID,MASTER_ID,SUBMIT_TAG,UNRESOLVED_HANDLING,SE_ID,CHILD_TAG,SE_VERSION,OWNER_ID,PARENT_ID,SCOPE_ID,IS_STATIC,IS_DISABLED,OLD_STATE,MERGE_MODE,STATE,JOB_ESD_ID,JOB_ESD_PREF,JOB_IS_FINAL,JOB_IS_RESTARTABLE,FINAL_ESD_ID,EXIT_CODE,COMMANDLINE,RR_COMMANDLINE,RERUN_SEQ,IS_REPLACED,IS_CANCELLED,BASE_SME_ID,REASON_SME_ID,FIRE_SME_ID,FIRE_SE_ID,TR_ID,TR_SD_ID_OLD,TR_SD_ID_NEW,TR_SEQ,WORKDIR,LOGFILE,ERRLOGFILE,PID,EXTPID,ERROR_MSG,KILL_ID,KILL_EXIT_CODE,IS_SUSPENDED,IS_SUSPENDED_LOCAL,PRIORITY,RAW_PRIORITY,NICE,NP_NICE,MIN_PRIORITY,AGING_AMOUNT,PARENT_SUSPENDED,CHILD_SUSPENDED,WARN_COUNT,WARN_LINK,SUBMIT_TS,RESUME_TS,SYNC_TS,RESOURCE_TS,RUNNABLE_TS,START_TS,FINSH_TS,FINAL_TS,IDLE_TIME,DEPENDENCY_WAIT_TIME,SUSPEND_TIME,SYNC_TIME,RESOURCE_TIME,JOBSERVER_TIME,RESTARTABLE_TIME,CHILD_WAIT_TIME,OP_SUSRES_TS,NPE_ID,TIME_ZONE,CREATOR_U_ID,CREATE_TS,CHANGER_U_ID,CHANGE_TS,PROCESS_TIME) AS
+CREATE VIEW SCI_SUBMITTED_ENTITY (ID,MASTER_ID,SUBMIT_TAG,UNRESOLVED_HANDLING,SE_ID,CHILD_TAG,SE_VERSION,OWNER_ID,PARENT_ID,SCOPE_ID,IS_STATIC,IS_DISABLED,OLD_STATE,MERGE_MODE,STATE,JOB_ESD_ID,JOB_ESD_PREF,JOB_IS_FINAL,JOB_IS_RESTARTABLE,FINAL_ESD_ID,EXIT_CODE,COMMANDLINE,RR_COMMANDLINE,RERUN_SEQ,IS_REPLACED,IS_CANCELLED,BASE_SME_ID,REASON_SME_ID,FIRE_SME_ID,FIRE_SE_ID,TR_ID,TR_SD_ID_OLD,TR_SD_ID_NEW,TR_SEQ,WORKDIR,LOGFILE,ERRLOGFILE,PID,EXTPID,ERROR_MSG,KILL_ID,KILL_EXIT_CODE,IS_SUSPENDED,IS_SUSPENDED_LOCAL,PRIORITY,RAW_PRIORITY,NICE,NP_NICE,MIN_PRIORITY,AGING_AMOUNT,PARENT_SUSPENDED,CHILD_SUSPENDED,WARN_COUNT,WARN_LINK,APPROVAL_MODE,CHILD_APPROVAL_MODE,SUBMIT_TS,RESUME_TS,SYNC_TS,RESOURCE_TS,RUNNABLE_TS,START_TS,FINSH_TS,FINAL_TS,IDLE_TIME,DEPENDENCY_WAIT_TIME,SUSPEND_TIME,SYNC_TIME,RESOURCE_TIME,JOBSERVER_TIME,RESTARTABLE_TIME,CHILD_WAIT_TIME,OP_SUSRES_TS,NPE_ID,TIME_ZONE,CREATOR_U_ID,CREATE_TS,CHANGER_U_ID,CHANGE_TS,PROCESS_TIME) AS
 SELECT 
     ID 
     , MASTER_ID                      AS MASTER_ID
@@ -161,6 +163,8 @@ SELECT
     , CHILD_SUSPENDED                AS CHILD_SUSPENDED
     , WARN_COUNT                     AS WARN_COUNT
     , WARN_LINK                      AS WARN_LINK
+    , APPROVAL_MODE                  AS APPROVAL_MODE
+    , CHILD_APPROVAL_MODE            AS CHILD_APPROVAL_MODE
     , dbinfo ('utc_to_datetime', round(mod(SUBMIT_TS, 1125899906842624)/1000)) AS SUBMIT_TS
     , dbinfo ('utc_to_datetime', round(mod(RESUME_TS, 1125899906842624)/1000)) AS RESUME_TS
     , dbinfo ('utc_to_datetime', round(mod(SYNC_TS, 1125899906842624)/1000)) AS SYNC_TS
@@ -242,6 +246,8 @@ CREATE TABLE ARC_SUBMITTED_ENTITY (
     , CHILD_SUSPENDED                int8             NULL
     , WARN_COUNT                     int8             NULL
     , WARN_LINK                      bigint           NULL
+    , APPROVAL_MODE                  int8             NULL
+    , CHILD_APPROVAL_MODE            int8             NULL
     , SUBMIT_TS                      bigint           NULL
     , RESUME_TS                      bigint           NULL
     , SYNC_TS                        bigint           NULL
