@@ -39,15 +39,17 @@ INSERT INTO GROUPS (ID, NAME,    DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGE
 --	Table "user"
 --------------------------------------------------------------------------------
 
-INSERT INTO USERS (ID, NAME,     PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
-	VALUES    (0,  'SYSTEM', 'ba143b7e 75dde00e 8f0fd6f4 6cf65faf', null, 0,      1,          81,           0,               0,              0,            0,         0,            0);
+INSERT INTO USERS (ID, NAME,           PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
+	VALUES    (0,  'SYSTEM',       'ba143b7e 75dde00e 8f0fd6f4 6cf65faf', null, 0,      1,          81,           0,               0,              0,            0,         0,            0);
 
-INSERT INTO USERS (ID, NAME,     PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
-	VALUES    (1,  'NOBODY', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx', null, 0,      0,          80,           0,               0,              0,            0,         0,            0);
+INSERT INTO USERS (ID, NAME,           PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
+	VALUES    (1,  'NOBODY',       'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx', null, 0,      0,          80,           0,               0,              0,            0,         0,            0);
  
-INSERT INTO USERS (ID, NAME,       PASSWD,                              SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
-	VALUES    (2,  'INTERNAL', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx', null, 0,    0,          81,           0,               0,              0,            0,         0,            0);
+INSERT INTO USERS (ID, NAME,           PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
+	VALUES    (2,  'INTERNAL',     'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx', null, 0,      0,          81,           0,               0,              0,            0,         0,            0);
 
+INSERT INTO USERS (ID, NAME,           PASSWD,                                SALT, METHOD, IS_ENABLED, DEFAULT_G_ID, CONNECTION_TYPE, DELETE_VERSION, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
+       VALUES     (3, 'FE_PROPERTIES', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx', null, 0,      0,          80,           0,               0,              0,            0,         0,            0);
 
 --------------------------------------------------------------------------------
 --	Table "SCHEDULING HIERARCHY"
@@ -113,3 +115,5 @@ INSERT INTO MEMBER (ID, G_ID, U_ID, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANG
 INSERT INTO MEMBER (ID, G_ID, U_ID, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
 	VALUES     (93, 81,   2,    0,            0,         0,            0);
 
+INSERT INTO MEMBER (ID, G_ID, U_ID, CREATOR_U_ID, CREATE_TS, CHANGER_U_ID, CHANGE_TS)
+        VALUES     (94, 80,   3,    0,            0,         0,            0);
