@@ -57,6 +57,8 @@ CREATE TABLE [SUBMITTED_ENTITY] (
     , [CHILD_SUSPENDED]              integer         NOT NULL
     , [WARN_COUNT]                   integer         NOT NULL
     , [WARN_LINK]                    decimal (38)        NULL
+    , [APPROVAL_MODE]                integer         NOT NULL
+    , [CHILD_APPROVAL_MODE]          integer         NOT NULL
     , [SUBMIT_TS]                    decimal (38)    NOT NULL
     , [RESUME_TS]                    decimal (38)        NULL
     , [SYNC_TS]                      decimal (38)        NULL
@@ -163,6 +165,8 @@ SELECT
     , [CHILD_SUSPENDED]              AS [CHILD_SUSPENDED]
     , [WARN_COUNT]                   AS [WARN_COUNT]
     , [WARN_LINK]                    AS [WARN_LINK]
+    , [APPROVAL_MODE]                AS [APPROVAL_MODE]
+    , [CHILD_APPROVAL_MODE]          AS [CHILD_APPROVAL_MODE]
     , dateadd(ss, round(([SUBMIT_TS] % 1125899906842624)/1000, 0), '1970-01-01') AS [SUBMIT_TS]
     , dateadd(ss, round(([RESUME_TS] % 1125899906842624)/1000, 0), '1970-01-01') AS [RESUME_TS]
     , dateadd(ss, round(([SYNC_TS] % 1125899906842624)/1000, 0), '1970-01-01') AS [SYNC_TS]
@@ -245,6 +249,8 @@ CREATE TABLE ARC_SUBMITTED_ENTITY (
     , [CHILD_SUSPENDED]              integer          NULL
     , [WARN_COUNT]                   integer          NULL
     , [WARN_LINK]                    decimal (38)     NULL
+    , [APPROVAL_MODE]                integer          NULL
+    , [CHILD_APPROVAL_MODE]          integer          NULL
     , [SUBMIT_TS]                    decimal (38)     NULL
     , [RESUME_TS]                    decimal (38)     NULL
     , [SYNC_TS]                      decimal (38)     NULL
